@@ -52,8 +52,13 @@
 #define MAKE_ARGB_RGB(r,g,b)		(((r&0xff) << 16) | ((g&0xff) <<  8) | (b&0xff))
 #define MAKE_ARGB_ARGB(a,r,g,b)		(((a&0xff) << 24) | ((r&0xff) << 16) | ((g&0xff) << 8) | (b&0xff))
 
+#if !defined(min)
 #define min(a,b)			(a < b ? a : b)
+#endif
+
+#if !defined(max)
 #define max(a,b)			(a > b ? a : b)
+#endif
 
 /* avoid direct floating point comparison */
 #define gdip_near_zero(value)		((value >= -0.0001f) && (value <= 0.0001f))
