@@ -1,7 +1,7 @@
 /**
  * matrix.c
  *
- * Copyright (C) Novell, Inc. 2003-2004.
+ * Copyright (C) Novell, Inc. 2003-2004, 2007.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy of this software 
  * and associated documentation files (the "Software"), to deal in the Software without restriction, 
@@ -23,8 +23,7 @@
  *
  **/
 
-#include <math.h>
-#include "matrix.h"
+#include "matrix-private.h"
 
 /*
 	GDI+ matrix takes 6 elements arranged in 3 rows by 2 columns. The identity matrix is
@@ -79,53 +78,17 @@ gdip_is_matrix_a_translation (GpMatrix *matrix)
 		(matrix->xy == 0.0f) && (matrix->yy == 1.0f));
 }
 
-
-/* public (exported) functions */
-
-GpStatus 
-GdipCreateMatrix (GpMatrix **matrix)
-{
-	GpMatrix *result;
-
-	g_return_val_if_fail  (matrix != NULL, InvalidParameter);
-	
-	result = GdipAlloc (sizeof (GpMatrix));
-	if (!result)
-		return OutOfMemory;
-
-	cairo_matrix_init_identity (result);
-
-	*matrix = result;
-	return Ok;
-}
-
+/* this helper function avoid GpMatrix allocation and reduce code duplication */
 GpStatus
-GdipCreateMatrix2 (float m11, float m12, float m21, float m22, float dx, float dy, GpMatrix **matrix)
+gdip_matrix_init_from_rect_3points (GpMatrix *matrix, const GpRectF *rect, const GpPointF *dstplg)
 {
-	GpMatrix *result;
-
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
-
-	result = GdipAlloc (sizeof (GpMatrix));
-	if (!result)
-		return OutOfMemory;
-
-	cairo_matrix_init (result, m11, m12, m21, m22, dx, dy);
-
-	*matrix = result;
-	return Ok;
-}
-
-GpStatus
-GdipCreateMatrix3 (const GpRectF *rect, const GpPointF *dstplg, GpMatrix **matrix)
-{
-	GpMatrix *result;
 	GpPointF *p, *p0, *p1, *p2;
 	double m11, m12, m21, m22;
 
-	g_return_val_if_fail (rect != NULL, InvalidParameter);
-	g_return_val_if_fail (dstplg != NULL, InvalidParameter);
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
+	if (!matrix || !rect || !dstplg)
+		return InvalidParameter;
+	if ((rect->Width == 0) || (rect->Height == 0))
+		return OutOfMemory;
 
 	p = (GpPointF*) dstplg;
 	p0 = p++;
@@ -137,56 +100,107 @@ GdipCreateMatrix3 (const GpRectF *rect, const GpPointF *dstplg, GpMatrix **matri
 	m21 = (p2->X - p0->X) / rect->Height;
 	m22 = (p2->Y - p0->Y) / rect->Height;
 
+	cairo_matrix_init (matrix, m11, m12, m21, m22, p0->X, p0->Y);
+	cairo_matrix_translate (matrix, -rect->X, -rect->Y);
+	return Ok;
+}
+
+/* public (exported) functions */
+
+// coverity[+alloc : arg-*0]
+GpStatus WINGDIPAPI
+GdipCreateMatrix (GpMatrix **matrix)
+{
+	GpMatrix *result;
+
+	if (!matrix)
+		return InvalidParameter;
+	
 	result = GdipAlloc (sizeof (GpMatrix));
 	if (!result)
 		return OutOfMemory;
 
-	cairo_matrix_init (result, m11, m12, m21, m22, p0->X, p0->Y);
-	cairo_matrix_translate (result, -rect->X, -rect->Y);
+	cairo_matrix_init_identity (result);
 
 	*matrix = result;
 	return Ok;
 }
 
-GpStatus
-GdipCreateMatrix3I (const GpRect *rect, const GpPoint *dstplg, GpMatrix **matrix)
+// coverity[+alloc : arg-*6]
+GpStatus WINGDIPAPI
+GdipCreateMatrix2 (float m11, float m12, float m21, float m22, float dx, float dy, GpMatrix **matrix)
 {
 	GpMatrix *result;
-	GpPoint *p, *p0, *p1, *p2;
-	double m11, m12, m21, m22;
 
-	g_return_val_if_fail (rect != NULL, InvalidParameter);
-	g_return_val_if_fail (dstplg != NULL, InvalidParameter);
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
-
-	p = (GpPoint*) dstplg;
-	p0 = p++;
-	p1 = p++;
-	p2 = p;
-
-	m11 = (p1->X - p0->X) / (double)rect->Width;
-	m12 = (p1->Y - p0->Y) / (double)rect->Width;
-	m21 = (p2->X - p0->X) / (double)rect->Height;
-	m22 = (p2->Y - p0->Y) / (double)rect->Height;
+	if (!matrix)
+		return InvalidParameter;
 
 	result = GdipAlloc (sizeof (GpMatrix));
 	if (!result)
 		return OutOfMemory;
 
-	cairo_matrix_init (result, m11, m12, m21, m22, p0->X, p0->Y);
-	cairo_matrix_translate (result, -rect->X, -rect->Y);
+	cairo_matrix_init (result, m11, m12, m21, m22, dx, dy);
 
 	*matrix = result;
-        return Ok;
+	return Ok;
 }
 
-GpStatus
+// coverity[+alloc : arg-*2]
+GpStatus WINGDIPAPI
+GdipCreateMatrix3 (GDIPCONST GpRectF *rect, GDIPCONST GpPointF *dstplg, GpMatrix **matrix)
+{
+	GpMatrix *result;
+	GpStatus status;
+
+	if (!rect || !dstplg || !matrix)
+		return InvalidParameter;
+
+	result = GdipAlloc (sizeof (GpMatrix));
+	if (!result)
+		return OutOfMemory;
+
+	status = gdip_matrix_init_from_rect_3points (result, rect, dstplg);
+	if (status == Ok)
+		*matrix = result;
+	else
+		GdipFree (result);
+
+	return status;
+}
+
+// coverity[+alloc : arg-*2]
+GpStatus WINGDIPAPI
+GdipCreateMatrix3I (GDIPCONST GpRect *rect, GDIPCONST GpPoint *dstplg, GpMatrix **matrix)
+{
+	GpRectF r;
+	GpPointF pts[3];
+
+	if (!rect || !dstplg || !matrix)
+		return InvalidParameter;
+
+	r.X = rect->X;
+	r.Y = rect->Y;
+	r.Width = rect->Width;
+	r.Height = rect->Height;
+
+	pts [0].X = dstplg [0].X;
+	pts [0].Y = dstplg [0].Y;
+	pts [1].X = dstplg [1].X;
+	pts [1].Y = dstplg [1].Y;
+	pts [2].X = dstplg [2].X;
+	pts [2].Y = dstplg [2].Y;
+
+        return GdipCreateMatrix3 (&r, (GpPointF*)&pts, matrix);
+}
+
+// coverity[+alloc : arg-*1]
+GpStatus WINGDIPAPI
 GdipCloneMatrix (GpMatrix *matrix, GpMatrix **cloneMatrix)
 {
 	GpMatrix *result;
 
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
-	g_return_val_if_fail (cloneMatrix != NULL, InvalidParameter);
+	if (!matrix || !cloneMatrix)
+		return InvalidParameter;
 
 	result = GdipAlloc (sizeof (GpMatrix));
 	if (!result)
@@ -198,29 +212,32 @@ GdipCloneMatrix (GpMatrix *matrix, GpMatrix **cloneMatrix)
 	return Ok;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipDeleteMatrix (GpMatrix *matrix)
 {
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
+	if (!matrix)
+		return InvalidParameter;
+
 	GdipFree (matrix);
         return Ok;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipSetMatrixElements (GpMatrix *matrix, float m11, float m12, float m21, float m22, float dx, float dy)
 {
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
+	if (!matrix)
+		return InvalidParameter;
        
 	cairo_matrix_init (matrix, m11, m12, m21, m22, dx, dy);
 	
 	return Ok;
 }
 
-GpStatus 
+GpStatus WINGDIPAPI
 GdipGetMatrixElements (GpMatrix *matrix, float *matrixOut)
 {
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
-	g_return_val_if_fail (matrixOut != NULL, InvalidParameter);
+	if (!matrix || !matrixOut)
+		return InvalidParameter;
 
         matrixOut[0] = (float) matrix->xx;
         matrixOut[1] = (float) matrix->yx;
@@ -232,11 +249,11 @@ GdipGetMatrixElements (GpMatrix *matrix, float *matrixOut)
         return Ok;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipMultiplyMatrix (GpMatrix *matrix, GpMatrix *matrix2, GpMatrixOrder order)
 {
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
-	g_return_val_if_fail (matrix2 != NULL, InvalidParameter);
+	if (!matrix || !matrix2)
+		return InvalidParameter;
 
         if (order == MatrixOrderAppend)
                 cairo_matrix_multiply (matrix, matrix, matrix2);
@@ -248,7 +265,7 @@ GdipMultiplyMatrix (GpMatrix *matrix, GpMatrix *matrix2, GpMatrixOrder order)
 	return Ok;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipTranslateMatrix (GpMatrix *matrix, float offsetX, float offsetY, GpMatrixOrder order)
 {
         cairo_matrix_t tmp;
@@ -260,7 +277,7 @@ GdipTranslateMatrix (GpMatrix *matrix, float offsetX, float offsetY, GpMatrixOrd
         return s;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipScaleMatrix (GpMatrix *matrix, float scaleX, float scaleY, GpMatrixOrder order)
 {
         GpMatrix tmp;
@@ -272,7 +289,7 @@ GdipScaleMatrix (GpMatrix *matrix, float scaleX, float scaleY, GpMatrixOrder ord
         return s;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipRotateMatrix (GpMatrix *matrix, float angle, GpMatrixOrder order)
 {
 	cairo_matrix_t tmp;
@@ -286,7 +303,7 @@ GdipRotateMatrix (GpMatrix *matrix, float angle, GpMatrixOrder order)
         return s;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipShearMatrix (GpMatrix *matrix, float shearX, float shearY, GpMatrixOrder order)
 {
         cairo_matrix_t tmp;
@@ -298,23 +315,22 @@ GdipShearMatrix (GpMatrix *matrix, float shearX, float shearY, GpMatrixOrder ord
         return s;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipInvertMatrix (GpMatrix *matrix)
 {
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
+	if (!matrix)
+		return InvalidParameter;
 
         return gdip_get_status (
                 cairo_matrix_invert (matrix));
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipTransformMatrixPoints (GpMatrix *matrix, GpPointF *pts, int count)
 {
         int i;
 
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
-	g_return_val_if_fail (pts != NULL, InvalidParameter);
-	if (count < 1)
+	if (!matrix || !pts || (count < 1))
 		return InvalidParameter;
         
         for (i = 0; i < count; i++, pts++) {
@@ -329,14 +345,12 @@ GdipTransformMatrixPoints (GpMatrix *matrix, GpPointF *pts, int count)
         return Ok;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipTransformMatrixPointsI (GpMatrix *matrix, GpPoint *pts, int count)
 {
         int i;
 
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
-	g_return_val_if_fail (pts != NULL, InvalidParameter);
-	if (count < 1)
+	if (!matrix || !pts || (count < 1))
 		return InvalidParameter;
         
         for (i = 0; i < count; i++, pts++) {
@@ -351,14 +365,12 @@ GdipTransformMatrixPointsI (GpMatrix *matrix, GpPoint *pts, int count)
         return Ok;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipVectorTransformMatrixPoints (GpMatrix *matrix, GpPointF *pts, int count)
 {
         int i;
 
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
-	g_return_val_if_fail (pts != NULL, InvalidParameter);
-	if (count < 1)
+	if (!matrix || !pts || (count < 1))
 		return InvalidParameter;
 
         for (i = 0; i < count; i++, pts++) {
@@ -373,14 +385,12 @@ GdipVectorTransformMatrixPoints (GpMatrix *matrix, GpPointF *pts, int count)
         return Ok;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipVectorTransformMatrixPointsI (GpMatrix *matrix, GpPoint *pts, int count)
 {
         int i;
         
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
-	g_return_val_if_fail (pts != NULL, InvalidParameter);
-	if (count < 1)
+	if (!matrix || !pts || (count < 1))
 		return InvalidParameter;
 
         for (i = 0; i < count; i++, pts++) {
@@ -395,38 +405,23 @@ GdipVectorTransformMatrixPointsI (GpMatrix *matrix, GpPoint *pts, int count)
         return Ok;
 }
 
-GpStatus 
+GpStatus WINGDIPAPI
 GdipIsMatrixInvertible (GpMatrix *matrix, BOOL *result)
 {
 	cairo_status_t status;
 	cairo_matrix_t copy;
 
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
-	g_return_val_if_fail (result != NULL, InvalidParameter);
+	if (!matrix || !result)
+		return InvalidParameter;
 
 	gdip_cairo_matrix_copy (&copy, matrix);
 	status = cairo_matrix_invert (&copy);
 
-        if (status == CAIRO_STATUS_INVALID_MATRIX)
-                *result = 0;
-	else
-	        *result = 1;
-
+        *result = (status != CAIRO_STATUS_INVALID_MATRIX);
         return Ok;
 }
 
-static bool
-matrix_equals (GpMatrix *x, GpMatrix *y)
-{
-	if ((x->xx != y->xx) || (x->yx != y->yx) || (x->xy != y->xy) ||
-	    (x->yy != y->yy) || (x->x0 != y->x0) || (x->y0 != y->y0))
-	  return FALSE;
-	
-	return TRUE;
-	
-}
-
-GpStatus
+GpStatus WINGDIPAPI
 GdipIsMatrixIdentity (GpMatrix *matrix, BOOL *result)
 {
 	if (!matrix || !result)
@@ -437,13 +432,13 @@ GdipIsMatrixIdentity (GpMatrix *matrix, BOOL *result)
         return Ok;
 }
 
-GpStatus
+GpStatus WINGDIPAPI
 GdipIsMatrixEqual (GpMatrix *matrix, GpMatrix *matrix2, BOOL *result)
 {
-	g_return_val_if_fail (matrix != NULL, InvalidParameter);
-	g_return_val_if_fail (matrix2 != NULL, InvalidParameter);
-	g_return_val_if_fail (result != NULL, InvalidParameter);
+	if (!matrix || !matrix2 || !result)
+		return InvalidParameter;
 
-        *result = matrix_equals (matrix, matrix2);
+        *result = ((matrix->xx == matrix2->xx) && (matrix->yx == matrix2->yx) && (matrix->xy == matrix2->xy) &&
+		(matrix->yy == matrix2->yy) && (matrix->x0 == matrix2->x0) && (matrix->y0 == matrix2->y0));
         return Ok;
 }
